@@ -77,7 +77,7 @@ def main():
 
         configure_logger("dap", LOG_LEVEL, LOG_FILENAME)
         log = get_logger("robotframework_debug_adapter.__main__")
-        log_args_and_python(log, sys.argv, robotframework_ls.__version__)
+        log_args_and_python(log, sys.argv, robotframework_ls)
 
         from robocorp_ls_core.debug_adapter_core.debug_adapter_threads import (
             reader_thread,
