@@ -16,7 +16,7 @@
 # limitations under the License.
 import json
 from robotframework_debug_adapter.constants import DEBUG
-from robotframework_debug_adapter.dap import dap_base_schema as base_schema
+from robocorp_ls_core.debug_adapter_core.dap import dap_base_schema as base_schema
 from robocorp_ls_core.robotframework_log import get_logger
 
 log = get_logger(__name__)
@@ -50,7 +50,7 @@ class DebugAdapterComm(object):
 
     def from_client(self, protocol_message):
 
-        from robotframework_debug_adapter.debug_adapter_threads import (
+        from robocorp_ls_core.debug_adapter_core.debug_adapter_threads import (
             READER_THREAD_STOPPED,
         )
 
@@ -81,7 +81,7 @@ class DebugAdapterComm(object):
         """
         :param InitializeRequest request:
         """
-        from robotframework_debug_adapter.dap.dap_base_schema import build_response
+        from robocorp_ls_core.debug_adapter_core.dap.dap_base_schema import build_response
 
         # : :type initialize_response: InitializeResponse
         # : :type body: Capabilities
@@ -96,9 +96,9 @@ class DebugAdapterComm(object):
         """
         :param LaunchRequest request:
         """
-        from robotframework_debug_adapter.dap.dap_base_schema import build_response
+        from robocorp_ls_core.debug_adapter_core.dap.dap_base_schema import build_response
         from robotframework_debug_adapter.launch_process import LaunchProcess
-        from robotframework_debug_adapter.dap.dap_schema import InitializedEvent
+        from robocorp_ls_core.debug_adapter_core.dap.dap_schema import InitializedEvent
 
         # : :type launch_response: LaunchResponse
         launch_response = build_response(request)
@@ -131,7 +131,7 @@ class DebugAdapterComm(object):
         """
         :param ConfigurationDoneRequest request:
         """
-        from robotframework_debug_adapter.dap.dap_base_schema import build_response
+        from robocorp_ls_core.debug_adapter_core.dap.dap_base_schema import build_response
 
         configuration_done_response = build_response(request)
         launch_process = self._launch_process
@@ -194,9 +194,9 @@ class DebugAdapterComm(object):
         """
         :param SetBreakpointsRequest request:
         """
-        from robotframework_debug_adapter.dap.dap_schema import SourceBreakpoint
-        from robotframework_debug_adapter.dap.dap_schema import Breakpoint
-        from robotframework_debug_adapter.dap.dap_schema import (
+        from robocorp_ls_core.debug_adapter_core.dap.dap_schema import SourceBreakpoint
+        from robocorp_ls_core.debug_adapter_core.dap.dap_schema import Breakpoint
+        from robocorp_ls_core.debug_adapter_core.dap.dap_schema import (
             SetBreakpointsResponseBody,
         )
 
